@@ -15,12 +15,11 @@
 # under the License.
 
 import contextlib
-import hashlib
 import logging
 
 from oslo_utils import encodeutils
+from oslo_utils.secretutils import md5
 import psycopg2
-import six
 
 import tooz
 from tooz import _retry
@@ -72,7 +71,7 @@ def _format_exception(e):
             attr_value = getattr(e.diag, attr_name)
             if attr_value is None:
                 continue
-            diagnostic_lines.append("  %s = %s" (attr_name, attr_value))
+            diagnostic_lines.append("  %s = %s" % (attr_name, attr_value))
         if diagnostic_lines:
             lines.append('Diagnostics:')
             lines.extend(diagnostic_lines)
@@ -99,12 +98,9 @@ class PostgresLock(locking.Lock):
         self._conn = None
         self._parsed_url = parsed_url
         self._options = options
-        h = hashlib.md5()
+        h = md5(usedforsecurity=False)
         h.update(name)
-        if six.PY2:
-            self.key = list(map(ord, h.digest()[0:2]))
-        else:
-            self.key = h.digest()[0:2]
+        self.key = h.digest()[0:2]
 
     def acquire(self, blocking=True, shared=False):
 
@@ -146,7 +142,8 @@ class PostgresLock(locking.Lock):
         try:
             return _lock()
         except Exception:
-            self._conn.close()
+            if self._conn:
+                self._conn.close()
             raise
 
     def release(self):
@@ -173,6 +170,10 @@ class PostgresDriver(coordination.CoordinationDriver):
     missing some functionality but in the future these not implemented API(s)
     will be filled in.
 
+    The PostgreSQL driver connection URI should look like::
+
+      postgresql://[USERNAME[:PASSWORD]@]HOST:PORT?dbname=DBNAME
+
     .. _PostgreSQL: http://www.postgresql.org/
     """
 
@@ -189,7 +190,7 @@ class PostgresDriver(coordination.CoordinationDriver):
 
     def __init__(self, member_id, parsed_url, options):
         """Initialize the PostgreSQL driver."""
-        super(PostgresDriver, self).__init__(member_id)
+        super(PostgresDriver, self).__init__(member_id, parsed_url, options)
         self._parsed_url = parsed_url
         self._options = utils.collapse(options)
 
