@@ -257,6 +257,7 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
         'retry_on_timeout',
         'socket_keepalive',
         'socket_timeout',
+        'socket_connect_timeout',
         'ssl',
         'ssl_certfile',
         'ssl_keyfile',
@@ -288,7 +289,12 @@ class RedisDriver(coordination.CoordinationDriverCachedRunWatchers,
     CLIENT_INT_ARGS = frozenset([
         'db',
         'socket_keepalive',
+    ])
+
+    #: Client arguments that are expected to be float convertible.
+    CLIENT_FLOAT_ARGS = frozenset([
         'socket_timeout',
+        'socket_connect_timeout',
     ])
 
     #: Default socket timeout to use when none is provided.
@@ -432,6 +438,8 @@ return 1
                 v = options[a]
             elif a in cls.CLIENT_INT_ARGS:
                 v = int(options[a])
+            elif a in cls.CLIENT_FLOAT_ARGS:
+                v = float(options[a])
             else:
                 v = options[a]
             kwargs[a] = v
